#Added by slkbuild 1.4.3
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
dotnew etc/slkbuild/SLKBUILD
dotnew etc/slkbuild/SLKBUILD.gconf
dotnew etc/slkbuild/SLKBUILD.mateconf
dotnew etc/slkbuild/SLKBUILD.perl
dotnew etc/slkbuild/SLKBUILD.python
dotnew etc/slkbuild/SLKBUILD.waf
